@@ -78,14 +78,17 @@ namespace gcs
             void set_name(Glib::ustring name);
             /** Gets the red component */
             gint get_red(void) const;
+            float get_red_p(void) const { return pColor->get_red_p(); }
             /** Sets the red component.  Must also update h, s, and v */
             void set_red(const gint r);	// must update h, s, v
             /** Gets the green component */
             gint get_green(void) const;
+            float get_green_p(void) const { return pColor->get_green_p(); }
             /** Sets the green component.  Must also update h, s, and v */
             void set_green(const gint g);	// must update h, s, v
             /** Gets the blue component */
             gint get_blue(void) const;
+            float get_blue_p(void) const { return pColor->get_blue_p(); }
             /** Sets the blue component.  Must also update h, s, and v */
             void set_blue(const gint b);	// must update h, s, v
             /** Gets the hue component */
