@@ -45,20 +45,16 @@ namespace gcs
             static void set_window_width(int w);
             static int get_window_height(void);
             static void set_window_height(int h);
+            static int get_favorites_width(void);
+            static void set_favorites_width(int w);
+            static bool get_palette_expanded(void);
+            static void set_palette_expanded(bool expanded);
 
             static Glib::ustring get_favorites_file(void);
             static Glib::ustring get_conf_dir(void);
+            static Glib::ustring get_user_palette_dir(void);
 
-            static const Glib::ustring APP_DIR;
-            static const Glib::ustring KEY_LAST_SAVE_DIR;
-            static const Glib::ustring KEY_LAST_COLOR;
-            static const Glib::ustring KEY_LAST_SCHEME_TYPE;
-            static const Glib::ustring KEY_WINDOW_WIDTH;
-            static const Glib::ustring KEY_WINDOW_HEIGHT;
-            static const Glib::ustring FAVORITES_FILE;
-            static const Glib::ustring GCS_CONF_DIR;
-            static const Glib::ustring OLD_GCS_CONF_DIR;
-            static const Glib::ustring USER_PALETTE_DIR;
+            static void migrate_old_config_directory();
 
             // window / ui settings
             static const int WINDOW_BORDER;
@@ -66,7 +62,24 @@ namespace gcs
             static const int UI_SPACING_MEDIUM;
             static const int UI_SPACING_LARGE;
 
-            static void migrate_old_config_directory();
+        private:
+            template <typename T>
+            static bool get_value(Glib::ustring gconf_key, T& result);
+            template <typename T>
+            static void set_value(Glib::ustring gconf_key, const T& val);
+
+            static const Glib::ustring APP_DIR;
+            static const Glib::ustring KEY_LAST_SAVE_DIR;
+            static const Glib::ustring KEY_LAST_COLOR;
+            static const Glib::ustring KEY_LAST_SCHEME_TYPE;
+            static const Glib::ustring KEY_WINDOW_WIDTH;
+            static const Glib::ustring KEY_WINDOW_HEIGHT;
+            static const Glib::ustring KEY_FAVORITES_WIDTH;
+            static const Glib::ustring KEY_PALETTE_EXPANDED;
+            static const Glib::ustring FAVORITES_FILE;
+            static const Glib::ustring GCS_CONF_DIR;
+            static const Glib::ustring OLD_GCS_CONF_DIR;
+            static const Glib::ustring USER_PALETTE_DIR;
     };
 } // namespace gcs
 
