@@ -25,6 +25,7 @@
 
 #include <vector>
 #include <gtk/gtk.h>
+#include <libgnome/gnome-help.h>
 #include <gtkmm/iconfactory.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/clipboard.h>
@@ -111,11 +112,12 @@ namespace gcs
 
         /* The Help menu */
         m_refActionGroup->add(Gtk::Action::create("MenuHelp", _("_Help")));
-        m_refActionGroup->add(Gtk::Action::create("Contents", Gtk::Stock::HELP),
+        m_refActionGroup->add(Gtk::Action::create("Contents", Gtk::Stock::HELP, _("_Contents"), _("Open the Agave manual")),
+                Gtk::AccelKey("F1"),
                 sigc::mem_fun(*this, &MainWindow::on_action_help_contents));   
         // Gtk::Stock::About requires gtkmm 2.6
         m_refActionGroup->add(Gtk::Action::create("About", Gtk::Stock::ABOUT),
-                sigc::mem_fun(*this, &MainWindow::on_action_help_about));   
+                sigc::mem_fun(*this, &MainWindow::on_action_help_about));
 
 
         // History Navigation
@@ -209,7 +211,7 @@ namespace gcs
         palettes.push_back(AGAVE_PALETTEDIR "/Web.gpl");
         palettes.push_back(AGAVE_PALETTEDIR "/Visibone.gpl");
         palettes.push_back(AGAVE_PALETTEDIR "/Ximian-Palette.gpl");
-        m_PaletteView->set_from_file(palettes[i % palettes.size()]);
+        m_palette_view->set_from_file(palettes[i % palettes.size()]);
         i++;
     }
 
@@ -230,7 +232,7 @@ namespace gcs
             filename = save_dialog.get_filename();
         }
         LOG("saving file to " << filename);
-        m_pBookmarkList->save_to_disk(filename);
+        m_bookmark_list->save_to_disk(filename);
     }
 
 
@@ -249,6 +251,9 @@ namespace gcs
     /* Help Menu Actions */
     void MainWindow::on_action_help_contents(void)
     {
+        gnome_help_display("agave.xml",
+                NULL /* link id */,
+                NULL /* GError */);
     }
 
 
@@ -257,7 +262,6 @@ namespace gcs
         m_pAbout->show();
     }
 
-
     void MainWindow::on_action_history_back(void)
     {
         LOG("Going Back");
@@ -276,7 +280,7 @@ namespace gcs
 
     void MainWindow::on_action_lighten_scheme(void)
     {
-        ColorPtr clr = Color::create(m_pColorButton->get_color());
+        ColorPtr clr = Color::create(m_color_button->get_color());
         // bump value by 5%
         clr->set_value(static_cast<int>(0.05 * maxSvValue + clr->get_value()));
         set_color(clr);
@@ -285,7 +289,7 @@ namespace gcs
 
     void MainWindow::on_action_darken_scheme(void)
     {
-        ColorPtr clr = Color::create(m_pColorButton->get_color());
+        ColorPtr clr = Color::create(m_color_button->get_color());
         // decrease value by 5%
         clr->set_value(static_cast<int>(clr->get_value() - 0.05 * maxSvValue));
         set_color(clr);
@@ -294,7 +298,7 @@ namespace gcs
 
     void MainWindow::on_action_saturate_scheme(void)
     {
-        ColorPtr clr = Color::create(m_pColorButton->get_color());
+        ColorPtr clr = Color::create(m_color_button->get_color());
         // increase saturation by 5%
         clr->set_saturation(static_cast<int>(clr->get_saturation() + 0.05 * maxSvValue));
         set_color(clr);
@@ -303,7 +307,7 @@ namespace gcs
 
     void MainWindow::on_action_desaturate_scheme(void)
     {
-        ColorPtr clr = Color::create(m_pColorButton->get_color());
+        ColorPtr clr = Color::create(m_color_button->get_color());
         // decrease value by 5%
         clr->set_saturation(static_cast<int>(clr->get_saturation() - 0.05 * maxSvValue));
         set_color(clr);
@@ -381,15 +385,15 @@ namespace gcs
 
     void MainWindow::on_action_add_bookmark(void)
     {
-        ColorPtr clr = Color::create(m_pColorButton->get_color());
-        m_pBookmarkList->add(clr);
+        ColorPtr clr = Color::create(m_color_button->get_color());
+        m_bookmark_list->add(clr);
         update_bookmark_actions();
     }
 
 
     void MainWindow::on_action_remove_bookmark(void)
     {
-        m_pBookmarkList->remove_selected();
+        m_bookmark_list->remove_selected();
         update_bookmark_actions();
     }
 
@@ -397,16 +401,16 @@ namespace gcs
     void MainWindow::on_action_clear_bookmarks(void)
     {
         LOG("Clearing Bookmarks");
-        m_pBookmarkList->clear();
+        m_bookmark_list->clear();
         update_bookmark_actions();
     }
 
 
     void MainWindow::update_bookmark_actions(void)
     {
-        m_refActionGroup->get_action("RemoveBookmark")->set_sensitive(!m_pBookmarkList->empty()
-                && m_pBookmarkList->count_selected());
-        m_refActionGroup->get_action("ClearBookmarks")->set_sensitive(!m_pBookmarkList->empty());
+        m_refActionGroup->get_action("RemoveBookmark")->set_sensitive(!m_bookmark_list->empty()
+                && m_bookmark_list->count_selected());
+        m_refActionGroup->get_action("ClearBookmarks")->set_sensitive(!m_bookmark_list->empty());
     }
 
 
