@@ -110,8 +110,15 @@ namespace pp
     {
         if (in)
         {
-            in >> *this;
-            return true;
+            try {
+                in >> *this;
+                return true;
+            }
+            catch (const std::exception& error)
+            {
+                std::cerr << error.what () << std::endl;
+            }
+            // fall through to return false
         }
         return false;
     }
@@ -124,6 +131,11 @@ namespace pp
         LOG("Parsing Palette");
         while (in.getline(line, N))
         {
+            if (!g_utf8_validate (line, -1, NULL))
+            {
+                g_warning ("Palette files must be encoded in UTF-8");
+                continue;
+            }
             p.m_emptyFile = false;
             p.m_currentLine++;
             // check if the line starts with the phrase GIMP Palette
