@@ -28,6 +28,7 @@
 
 #include <iostream>
 #include <vector>
+#include <cstring>
 #include <glibmm/ustring.h>
 #include "core/gcs-types.h"
 #include "core/gcs-color.h"
@@ -151,14 +152,16 @@ namespace pp
    };
 
 
+   /** NOTE: line must be utf-8 encoded */
    Glib::ustring Palette::parse_name(const char* line) throw(ParseError)
    {
        const char* nm = "Name:";
+       const size_t nm_len = strlen(nm);
        // Make sure the line actually starts with "Name:"
        if (strstr(line, nm) == line)
        {
-           return trim(Glib::ustring(line + strlen(nm), strlen(line) -
-                       strlen(nm)));
+           return trim(Glib::ustring(line + nm_len, g_utf8_strlen(line, -1) -
+                       nm_len));
        }
        else
        {
@@ -166,6 +169,7 @@ namespace pp
        }
    }
 
+   /** NOTE: line must be utf-8 encoded */
    Palette::size_type Palette::parse_columns(const char* line) throw(ParseError)
    {
        const char* cols = "Columns:";
