@@ -25,6 +25,7 @@
 
 #include <list> // for list of drag targets
 #include <limits>   // for numeric_limits<>::max()
+#include <cmath>
 #include <gdkmm/gc.h>
 #include <pangomm/layout.h>
 #include <glibmm/ustring.h>
@@ -40,6 +41,31 @@ namespace gcs
     static const unsigned int GREEN_BYTE_POS = 2;
     static const unsigned int BLUE_BYTE_POS = 1;
 
+    static void
+        cairo_rounded_rectangle(cairo_t* cr, double x, double y, double width, double height, double radius)
+    {
+        //if there's no rounding, just use normal cairo_rectangle
+        if (radius == 0.0)
+        {
+            cairo_rectangle(cr, x, y, width, height);
+        }
+        else
+        {
+            // top left corner
+            cairo_arc(cr, x + radius, y + radius, radius, -M_PI, -M_PI / 2.0);
+            cairo_line_to(cr, x + width - radius, y);
+            // top right corner
+            cairo_arc(cr, x + width - radius, y + radius, radius, -M_PI / 2.0, 0.0);
+            cairo_line_to(cr, x + width, y + height - radius);
+            // bottom right corner
+            cairo_arc(cr, x + width - radius, y + height - radius, radius, 0.0, M_PI / 2.0);
+            cairo_line_to(cr, x + radius, y + height);
+            // bottom left corner
+            cairo_arc(cr, x + radius, y + height - radius, radius, M_PI / 2.0, -M_PI);
+            cairo_close_path(cr);
+        }
+    }
+
     namespace Widgets
     {
         ColorPtr ColorSwatch::m_white = gcs::Color::create("#FFFFFF");
@@ -49,7 +75,8 @@ namespace gcs
 
         ColorSwatch::ColorSwatch(ColorPtr bg) :
             m_background(bg), m_minSize(12),
-            m_borderWidth(1),
+            m_borderWidth(0),
+            m_cornerRadius(0),
             m_swatchPadding(6)
         {
             // if this is the first ColorSwatch, create a tooltip object and
@@ -65,7 +92,6 @@ namespace gcs
             m_colormap = get_default_colormap();
             m_colormap->alloc_color(m_black->gdk());
             m_colormap->alloc_color(m_white->gdk());
-            alloc_bg();
 
             // Targets for drag and drop:
             std::list<Gtk::TargetEntry> listTargets;
@@ -84,7 +110,6 @@ namespace gcs
         ColorSwatch::ColorSwatch(const ColorSwatch& c) :
             m_background(c.m_background)
         {
-            m_borderGC = c.m_borderGC;
             m_colormap = c.m_colormap;
         }
 
@@ -111,10 +136,6 @@ namespace gcs
             Glib::RefPtr<Gdk::Window> window = get_window();
             // set the size of the swatch.
             set_size_request(m_minSize, m_minSize);
-            m_borderGC = Gdk::GC::create(window);
-            m_borderGC->set_line_attributes(m_borderWidth, Gdk::LINE_SOLID,
-                    Gdk::CAP_BUTT, Gdk::JOIN_MITER);
-            m_borderGC->set_foreground(m_black->gdk());
             add_events(Gdk::BUTTON_PRESS_MASK | Gdk::ENTER_NOTIFY_MASK |
                     Gdk::LEAVE_NOTIFY_MASK);
             pTooltips->set_tip(*this, m_background->get_hexstring());
@@ -122,44 +143,37 @@ namespace gcs
 
 
         bool ColorSwatch::on_expose_event(GdkEventExpose *e)
-        {
-            redraw();
-            return true;
-        }
-
-
-        void ColorSwatch::redraw(void)
         {
             Glib::RefPtr<Gdk::Window> win = get_window();
-            win->set_background(m_background->gdk());
-            win->clear();
-            int winWidth, winHeight;
-            win->get_size(winWidth, winHeight);
-            /* First draw an outline around the edge (in black, i guess) */
+            // FIXME: use cairomm eventually
+            cairo_t* cr = gdk_cairo_create(win->gobj());
+            cairo_rectangle(cr, e->area.x, e->area.y, e->area.width, e->area.height);
+            cairo_clip(cr);
+            cairo_save(cr);
+            cairo_set_source_rgb(cr, m_background->get_red_p(),
+                    m_background->get_green_p(), m_background->get_blue_p());
+            cairo_rounded_rectangle(cr, static_cast<float>(m_borderWidth) / 2.0f,
+                    static_cast<float>(m_borderWidth) / 2.0f,
+                    get_width() - static_cast<float>(m_borderWidth),
+                    get_height() - static_cast<float>(m_borderWidth),
+                    m_cornerRadius);
+            cairo_fill_preserve(cr);
+            cairo_restore(cr);
             if (m_borderWidth > 0)
             {
-                win->draw_rectangle(m_borderGC, false, m_borderWidth/2, m_borderWidth/2,
-                        winWidth - m_borderWidth, winHeight - m_borderWidth);
+                //cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 0.4);
+                cairo_set_line_width(cr, static_cast<float>(m_borderWidth));
+                cairo_stroke(cr);
             }
-        }
-
-
-        void ColorSwatch::alloc_bg(void)
-        {
-            m_colormap->alloc_color(m_background->gdk());
+            cairo_destroy(cr);
+            return true;
         }
 
 
         void ColorSwatch::set_color(ColorPtr bg)
         {
             m_background = bg;
-            alloc_bg();
-            //LOG("background_ = " << m_background);
-            redraw();
-            // Currently tooltips are only used for the palette, and we never
-            // change the color of those swatches, so this isn't really needed
-            // at this point.
-            //pTooltips->set_tip(*this, m_background->get_hexstring());
+            queue_draw();
         }
 
 
