@@ -35,12 +35,15 @@
 #include <gtkmm/box.h>
 #include <gtkmm/expander.h>
 #include <glibmm/ustring.h>
+#include <libglademm/xml.h>
 
 #include "core/gcs-types.h"
 #include "core/gcs-color.h"
 #include "paletteparser/palette.h"
 #include "palette-selector.h"
 
+using namespace Gnome;
+
 namespace gcs
 {
     class PaletteTreeModel;
@@ -50,9 +53,9 @@ namespace gcs
         class PaletteView : public Gtk::Expander
         {
             public:
-                PaletteView(Glib::ustring filename);
+                PaletteView(GtkExpander* cobject, Glib::RefPtr<Glade::Xml>& glade);
                 //~PaletteView();
-                bool set_from_file(Glib::ustring fname);
+                bool set_from_file(const Glib::ustring& fname);
 
                 sigc::signal<void, ColorPtr>& signal_color_selected() {
                     return m_signal_color_selected; }
@@ -63,32 +66,34 @@ namespace gcs
 
             protected:
                 bool on_color_selected(gint index);
-                void reset(void);
-                void populate(void);
+                void display_palette(const shared_ptr<pp::Palette>& palette);
 
                 /** triggered whenever the mouse pointer enters the palette
                  */
-                bool on_enter_palette(GdkEventCrossing* event);
+                bool on_enter_swatch(GdkEventCrossing* event);
 
                 /** triggered whenever the mouse pointer leaves the palette
                  */
-                bool on_leave_palette(GdkEventCrossing* event);
+                bool on_leave_swatch(GdkEventCrossing* event);
 
                 /** triggered when the combobox selection has changed
                  */
                 void on_palette_file_changed(void);
 
+                bool on_eventbox_expose(GdkEventExpose* e);
+
             private:
                 Gtk::Table m_table;
                 Gtk::EventBox m_eventBox;
                 Gtk::ScrolledWindow m_scrolledWindow;
                 sigc::signal<void, ColorPtr> m_signal_color_selected;
                 Glib::RefPtr<PaletteTreeModel> m_refPaletteModel;
-                pp::Palette m_palette;
+                shared_ptr<pp::Palette> m_palette;
+                shared_ptr<PaletteSelector> m_paletteSelector;
                 Gtk::VBox m_vbox;
-                PaletteSelector m_paletteSelector;
                 static const gint m_minCellSize;
                 static const gint m_minPaletteWidth;
+                static const gint m_maxVisibleRows;
                 static const gint m_maxPaletteHeight;
                 guint m_rows;
         };
