@@ -32,40 +32,41 @@ namespace gcs
     namespace Widgets
     {
 
-        SchemeSelector::SchemeSelector(void)
-            : m_refListStore(Gtk::ListStore::create(m_columns))
-            {
+        SchemeSelector::SchemeSelector(GtkComboBox* cobject, Glib::RefPtr<Glade::Xml>& glade) :
+            Gtk::ComboBox(cobject),
+            m_refListStore(Gtk::ListStore::create(m_columns))
+        {
 
-                // Add items to the model
-                Gtk::TreeModel::Row row;
-                row = *(m_refListStore->append());
-                row[m_columns.m_columnText] = _("Complements");
-                row[m_columns.m_columnCode] = SCHEME_COMPLEMENTS;
-                row = *(m_refListStore->append());
-                row[m_columns.m_columnText] = _("Split-Complements");
-                row[m_columns.m_columnCode] = SCHEME_SPLIT_COMPLEMENTS;
-                row = *(m_refListStore->append());
-                row[m_columns.m_columnText] = _("Triads");
-                row[m_columns.m_columnCode] = SCHEME_TRIADS;
-                row = *(m_refListStore->append());
-                row[m_columns.m_columnText] = _("Tetrads");
-                row[m_columns.m_columnCode] = SCHEME_TETRADS;
-                row = *(m_refListStore->append());
-                row[m_columns.m_columnText] = _("Analogous");
-                row[m_columns.m_columnCode] = SCHEME_ANALOGOUS;
-                row = *(m_refListStore->append());
-                row[m_columns.m_columnText] = _("Monochromatic");
-                row[m_columns.m_columnCode] = SCHEME_MONOCHROMATIC;
+            // Add items to the model
+            Gtk::TreeModel::Row row;
+            row = *(m_refListStore->append());
+            row[m_columns.m_columnText] = _("Complements");
+            row[m_columns.m_columnCode] = SCHEME_COMPLEMENTS;
+            row = *(m_refListStore->append());
+            row[m_columns.m_columnText] = _("Split-Complements");
+            row[m_columns.m_columnCode] = SCHEME_SPLIT_COMPLEMENTS;
+            row = *(m_refListStore->append());
+            row[m_columns.m_columnText] = _("Triads");
+            row[m_columns.m_columnCode] = SCHEME_TRIADS;
+            row = *(m_refListStore->append());
+            row[m_columns.m_columnText] = _("Tetrads");
+            row[m_columns.m_columnCode] = SCHEME_TETRADS;
+            row = *(m_refListStore->append());
+            row[m_columns.m_columnText] = _("Analogous");
+            row[m_columns.m_columnCode] = SCHEME_ANALOGOUS;
+            row = *(m_refListStore->append());
+            row[m_columns.m_columnText] = _("Monochromatic");
+            row[m_columns.m_columnCode] = SCHEME_MONOCHROMATIC;
 
-                set_model(m_refListStore);
+            set_model(m_refListStore);
 
-                // Display the m_columnText column in the ComboBox
-                pack_start(m_columns.m_columnText);
+            // Display the m_columnText column in the ComboBox
+            pack_start(m_columns.m_columnText);
 
-                // set the first choice as the active item
-                set_scheme_type(SCHEME_TRIADS);
+            // set the first choice as the active item
+            set_scheme_type(SCHEME_TRIADS);
 
-            }
+        }
 
 
         SchemeSelector::~SchemeSelector(void)
